#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_PREV_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_PREV_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/prev.hpp>

#endif
